{ config, pkgs, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
  ];

  networking = {
    hostName = "edison";
    defaultGateway = "192.168.10.1";
    nameservers = [ "192.168.11.100" "1.1.1.1" ];
    interfaces.eno1.ipv4 = {
      addresses = [
      { address = "192.168.10.170"; prefixLength = 24; }
      ];
    };
    hostId = "8f84a235";
  };

  # sops.defaultSopsFile = ../../secrets/edison/edison.yaml;

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    ((vim_configurable.override {  }).customize{
     name = "vim";
     vimrcConfig.packages.myplugins = with pkgs.vimPlugins; {
     start = [ vim-nix vim-lastplace vim-commentary ];
     opt = [];
     };
     vimrcConfig.customRC = ''
     " your custom vimrc
     set number
     set relativenumber
     set nu rnu
     set signcolumn=number

     set hlsearch
     set smartcase
     set incsearch

     set autoindent
     set expandtab
     set shiftwidth=2
     set tabstop=2
     set smartindent
     set smarttab

     set ruler

     set undolevels=1000

     set nocompatible
     set backspace=indent,eol,start
     " Turn on syntax highlighting by default
     syntax on
     " ...
     '';
    }
  )
  ];

  networking.firewall.allowedTCPPorts = [ 22 ];

  system.stateVersion = "23.05";
}

